@@ -96,6 +96,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_codecommit
@@ -158,9 +160,9 @@ class CfnEnvironmentEC2(
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]] = None,
+        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union["CfnEnvironmentEC2.RepositoryProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Create a new ``AWS::Cloud9::EnvironmentEC2``.
 
@@ -177,6 +179,10 @@ class CfnEnvironmentEC2(
         :param subnet_id: The ID of the subnet in Amazon Virtual Private Cloud (Amazon VPC) that AWS Cloud9 will use to communicate with the Amazon Elastic Compute Cloud (Amazon EC2) instance.
         :param tags: An array of key-value pairs that will be associated with the new AWS Cloud9 development environment.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEnvironmentEC2.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnEnvironmentEC2Props(
             instance_type=instance_type,
             automatic_stop_time_minutes=automatic_stop_time_minutes,
@@ -198,6 +204,9 @@ class CfnEnvironmentEC2(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEnvironmentEC2.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -208,6 +217,9 @@ class CfnEnvironmentEC2(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEnvironmentEC2._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -259,6 +271,9 @@ class CfnEnvironmentEC2(
 
     @instance_type.setter
     def instance_type(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "instance_type").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceType", value)
 
     @builtins.property # type: ignore[misc]
@@ -272,6 +287,9 @@ class CfnEnvironmentEC2(
 
     @automatic_stop_time_minutes.setter
     def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "automatic_stop_time_minutes").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "automaticStopTimeMinutes", value)
 
     @builtins.property # type: ignore[misc]
@@ -287,6 +305,9 @@ class CfnEnvironmentEC2(
 
     @connection_type.setter
     def connection_type(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "connection_type").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionType", value)
 
     @builtins.property # type: ignore[misc]
@@ -300,6 +321,9 @@ class CfnEnvironmentEC2(
 
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
     @builtins.property # type: ignore[misc]
@@ -329,6 +353,9 @@ class CfnEnvironmentEC2(
 
     @image_id.setter
     def image_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "image_id").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageId", value)
 
     @builtins.property # type: ignore[misc]
@@ -342,6 +369,9 @@ class CfnEnvironmentEC2(
 
     @name.setter
     def name(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
     @builtins.property # type: ignore[misc]
@@ -357,6 +387,9 @@ class CfnEnvironmentEC2(
 
     @owner_arn.setter
     def owner_arn(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "owner_arn").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ownerArn", value)
 
     @builtins.property # type: ignore[misc]
@@ -375,6 +408,9 @@ class CfnEnvironmentEC2(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnEnvironmentEC2.RepositoryProperty", aws_cdk.core.IResolvable]]]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "repositories").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositories", value)
 
     @builtins.property # type: ignore[misc]
@@ -388,6 +424,9 @@ class CfnEnvironmentEC2(
 
     @subnet_id.setter
     def subnet_id(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnEnvironmentEC2, "subnet_id").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "subnetId", value)
 
     @jsii.data_type(
@@ -424,6 +463,10 @@ class CfnEnvironmentEC2(
                     repository_url="repositoryUrl"
                 )
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(CfnEnvironmentEC2.RepositoryProperty.__init__)
+                check_type(argname="argument path_component", value=path_component, expected_type=type_hints["path_component"])
+                check_type(argname="argument repository_url", value=repository_url, expected_type=type_hints["repository_url"])
             self._values: typing.Dict[str, typing.Any] = {
                 "path_component": path_component,
                 "repository_url": repository_url,
@@ -492,9 +535,9 @@ class CfnEnvironmentEC2Props:
         image_id: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
         owner_arn: typing.Optional[builtins.str] = None,
-        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[CfnEnvironmentEC2.RepositoryProperty, aws_cdk.core.IResolvable]]]] = None,
+        repositories: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[typing.Union[CfnEnvironmentEC2.RepositoryProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]]]] = None,
         subnet_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Sequence[aws_cdk.core.CfnTag]] = None,
+        tags: typing.Optional[typing.Sequence[typing.Union[aws_cdk.core.CfnTag, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Properties for defining a ``CfnEnvironmentEC2``.
 
@@ -539,6 +582,18 @@ class CfnEnvironmentEC2Props:
                 )]
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnEnvironmentEC2Props.__init__)
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument automatic_stop_time_minutes", value=automatic_stop_time_minutes, expected_type=type_hints["automatic_stop_time_minutes"])
+            check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument image_id", value=image_id, expected_type=type_hints["image_id"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument owner_arn", value=owner_arn, expected_type=type_hints["owner_arn"])
+            check_type(argname="argument repositories", value=repositories, expected_type=type_hints["repositories"])
+            check_type(argname="argument subnet_id", value=subnet_id, expected_type=type_hints["subnet_id"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "instance_type": instance_type,
         }
@@ -733,6 +788,10 @@ class CloneRepository(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CloneRepository.from_code_commit)
+            check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("CloneRepository", jsii.sinvoke(cls, "fromCodeCommit", [repository, path]))
 
     @builtins.property # type: ignore[misc]
@@ -794,7 +853,7 @@ class Ec2EnvironmentProps:
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Properties for Ec2Environment.
 
@@ -835,6 +894,15 @@ class Ec2EnvironmentProps:
         '''
         if isinstance(subnet_selection, dict):
             subnet_selection = aws_cdk.aws_ec2.SubnetSelection(**subnet_selection)
+        if __debug__:
+            type_hints = typing.get_type_hints(Ec2EnvironmentProps.__init__)
+            check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument cloned_repositories", value=cloned_repositories, expected_type=type_hints["cloned_repositories"])
+            check_type(argname="argument connection_type", value=connection_type, expected_type=type_hints["connection_type"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument subnet_selection", value=subnet_selection, expected_type=type_hints["subnet_selection"])
         self._values: typing.Dict[str, typing.Any] = {
             "vpc": vpc,
         }
@@ -1051,7 +1119,7 @@ class Ec2Environment(
         description: typing.Optional[builtins.str] = None,
         ec2_environment_name: typing.Optional[builtins.str] = None,
         instance_type: typing.Optional[aws_cdk.aws_ec2.InstanceType] = None,
-        subnet_selection: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
+        subnet_selection: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -1066,6 +1134,10 @@ class Ec2Environment(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Ec2Environment.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Ec2EnvironmentProps(
             vpc=vpc,
             cloned_repositories=cloned_repositories,
@@ -1094,6 +1166,11 @@ class Ec2Environment(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Ec2Environment.from_ec2_environment_name)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument ec2_environment_name", value=ec2_environment_name, expected_type=type_hints["ec2_environment_name"])
         return typing.cast(IEc2Environment, jsii.sinvoke(cls, "fromEc2EnvironmentName", [scope, id, ec2_environment_name]))
 
     @builtins.property # type: ignore[misc]
